@@ -262,8 +262,8 @@ def create_measurement_layer(file: RDYFile, t_lim: Tuple[np.datetime64, np.datet
     file_message.value = f"<p>Filename: {str(file.filename or '')}" \
                          f"<br>Device: {str(getattr(file.device, 'manufacturer', ''))} " \
                          f"{str(getattr(file.device, 'model', ''))}</p>" + \
-                         f"<br>Start time: {str(time[0] or 'n/a')}" + \
-                         f"<br>End time:   {str(time[-1] or 'n/a')}"
+                         f"<br>GPS Start time: {str(time[0] or 'n/a')}" + \
+                         f"<br>GPS End time:   {str(time[-1] or 'n/a')}"
 
     file_polyline.popup = file_message
     measurement_layer.add(file_polyline)
